==> hapi-base-2.3-sources.jar: ca/uhn/hl7v2/validation/impl/SizeRule.java <==
/**
The contents of this file are subject to the Mozilla Public License Version 1.1 
(the "License"); you may not use this file except in compliance with the License. 
You may obtain a copy of the License at http://www.mozilla.org/MPL/ 
Software distributed under the License is distributed on an "AS IS" basis, 
WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for the 
specific language governing rights and limitations under the License. 

The Original Code is "SizeRule.java".  Description: 
"Checks that Primitive values conform to a certain size limit" 

The Initial Developer of the Original Code is University Health Network. Copyright (C) 
2004.  All Rights Reserved. 

Contributor(s): ______________________________________. 

Alternatively, the contents of this file may be used under the terms of the 
GNU General Public License (the "GPL"), in which case the provisions of the GPL are 
applicable instead of those above.  If you wish to allow use of your version of this 
file only under the terms of the GPL and not to allow others to use your version 
of this file under the MPL, indicate your decision by deleting  the provisions above 
and replace  them with the notice and other provisions required by the GPL License.  
If you do not delete the provisions above, a recipient may use your version of 
this file under either the MPL or the GPL. 
 */
package ca.uhn.hl7v2.validation.impl;

import ca.uhn.hl7v2.validation.ValidationException;
import ca.uhn.hl7v2.validation.builder.BuilderSupport;

/**
 * Checks that Primitive values conform to a certain size limit.
 * 
 * @author Bryan Tripp
 * @version $Revision: 1.1 $ updated on $Date: 2007-02-19 02:24:40 $ by $Author: jamesagnew $
 * 
 * @deprecated use {@link BuilderSupport#maxLength()} instead
 */
@SuppressWarnings("serial")
public class SizeRule extends AbstractPrimitiveTypeRule {

	private int myMaxChars;

	/**
	 * @param theMaxChars the maximum number of characters this rule allows in a primitive value
	 */
	public SizeRule(int theMaxChars) {
		myMaxChars = theMaxChars;
	}

	/**
	 * @see ca.uhn.hl7v2.validation.Rule#apply(java.lang.Object)
	 */
	public ValidationException[] apply(String value) {
		return result(value == null || value.length() <= myMaxChars, value);
	}

	/**
	 * @see ca.uhn.hl7v2.validation.Rule#getDescription()
	 */
	public String getDescription() {
		return "%s exceeds the maximum size of " + myMaxChars + " characters";
	}

}

==> hapi-base-2.5-sources.jar: ca/uhn/hl7v2/validation/impl/SizeRule.java <==
/**
The contents of this file are subject to the Mozilla Public License Version 1.1 
(the "License"); you may not use this file except in compliance with the License. 
You may obtain a copy of the License at http://www.mozilla.org/MPL/ 
Software distributed under the License is distributed on an "AS IS" basis, 
WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for the 
specific language governing rights and limitations under the License. 

The Original Code is "SizeRule.java".  Description: 
"Checks that Primitive values conform to a certain size limit" 

The Initial Developer of the Original Code is University Health Network. Copyright (C) 
2004.  All Rights Reserved. 

Contributor(s): ______________________________________. 

Alternatively, the contents of this file may be used under the terms of the 
GNU General Public License (the "GPL"), in which case the provisions of the GPL are 
applicable instead of those above.  If you wish to allow use of your version of this 
file only under the terms of the GPL and not to allow others to use your version 
of this file under the MPL, indicate your decision by deleting  the provisions above 
and replace  them with the notice and other provisions required by the GPL License.  
If you do not delete the provisions above, a recipient may use your version of 
this file under either the MPL or the GPL. 
 */
package ca.uhn.hl7v2.validation.impl;

import ca.uhn.hl7v2.validation.ValidationException;
import ca.uhn.hl7v2.validation.builder.BuilderSupport;

/**
 * Checks that Primitive values conform to a certain size limit.
 * 
 * @author Bryan Tripp
 * @version $Revision: 1.1 $ updated on $Date: 2007-02-19 02:24:40 $ by $Author: jamesagnew $
 * 
 * @deprecated use {@link BuilderSupport#maxLength(int)} instead
 */
@SuppressWarnings("serial")
public class SizeRule extends AbstractPrimitiveTypeRule {

	private final int myMaxChars;

	/**
	 * @param theMaxChars the maximum number of characters this rule allows in a primitive value
	 */
	public SizeRule(int theMaxChars) {
		myMaxChars = theMaxChars;
	}

	/**
	 * @see ca.uhn.hl7v2.validation.Rule#apply(java.lang.Object)
	 */
	public ValidationException[] apply(String value) {
		return result(value == null || value.length() <= myMaxChars, value);
	}

	/**
	 * @see ca.uhn.hl7v2.validation.Rule#getDescription()
	 */
	public String getDescription() {
		return "%s exceeds the maximum size of " + myMaxChars + " characters";
	}

}
